@@ -20,6 +20,7 @@ from .literals import (
     ArtifactPackagingType,
     ArtifactsTypeType,
     AuthTypeType,
+    BatchReportModeTypeType,
     BucketOwnerAccessType,
     BuildBatchPhaseTypeType,
     BuildPhaseTypeType,
@@ -1280,6 +1281,7 @@ ProjectBuildBatchConfigTypeDef = TypedDict(
         "combineArtifacts": bool,
         "restrictions": "BatchRestrictionsTypeDef",
         "timeoutInMins": int,
+        "batchReportMode": BatchReportModeTypeType,
     },
     total=False,
 )
